@@ -1,7 +1,7 @@
 """
 Type annotations for honeycode service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,13 +17,13 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_honeycode.paginator import (
+from .paginator import (
     ListTableColumnsPaginator,
     ListTableRowsPaginator,
     ListTablesPaginator,
     QueryTableRowsPaginator,
 )
-from mypy_boto3_honeycode.type_defs import (
+from .type_defs import (
     BatchCreateTableRowsResultTypeDef,
     BatchDeleteTableRowsResultTypeDef,
     BatchUpdateTableRowsResultTypeDef,
@@ -78,8 +78,8 @@ class Exceptions:
 
 class HoneycodeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -93,16 +93,16 @@ class HoneycodeClient:
         clientRequestToken: str = None,
     ) -> BatchCreateTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch-create-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
+        [Show boto3-stubs documentation](./client.md#batch_create_table_rows)
         """
 
     def batch_delete_table_rows(
         self, workbookId: str, tableId: str, rowIds: List[str], clientRequestToken: str = None
     ) -> BatchDeleteTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch-delete-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
+        [Show boto3-stubs documentation](./client.md#batch_delete_table_rows)
         """
 
     def batch_update_table_rows(
@@ -113,8 +113,8 @@ class HoneycodeClient:
         clientRequestToken: str = None,
     ) -> BatchUpdateTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch-update-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
+        [Show boto3-stubs documentation](./client.md#batch_update_table_rows)
         """
 
     def batch_upsert_table_rows(
@@ -125,22 +125,22 @@ class HoneycodeClient:
         clientRequestToken: str = None,
     ) -> BatchUpsertTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch-upsert-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
+        [Show boto3-stubs documentation](./client.md#batch_upsert_table_rows)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def describe_table_data_import_job(
         self, workbookId: str, tableId: str, jobId: str
     ) -> DescribeTableDataImportJobResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#describe-table-data-import-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
+        [Show boto3-stubs documentation](./client.md#describe_table_data_import_job)
         """
 
     def generate_presigned_url(
@@ -151,8 +151,8 @@ class HoneycodeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_screen_data(
@@ -165,8 +165,8 @@ class HoneycodeClient:
         nextToken: str = None,
     ) -> GetScreenDataResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get-screen-data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
+        [Show boto3-stubs documentation](./client.md#get_screen_data)
         """
 
     def invoke_screen_automation(
@@ -180,16 +180,16 @@ class HoneycodeClient:
         clientRequestToken: str = None,
     ) -> InvokeScreenAutomationResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#invoke-screen-automation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
+        [Show boto3-stubs documentation](./client.md#invoke_screen_automation)
         """
 
     def list_table_columns(
         self, workbookId: str, tableId: str, nextToken: str = None
     ) -> ListTableColumnsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list-table-columns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
+        [Show boto3-stubs documentation](./client.md#list_table_columns)
         """
 
     def list_table_rows(
@@ -201,16 +201,16 @@ class HoneycodeClient:
         nextToken: str = None,
     ) -> ListTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
+        [Show boto3-stubs documentation](./client.md#list_table_rows)
         """
 
     def list_tables(
         self, workbookId: str, maxResults: int = None, nextToken: str = None
     ) -> ListTablesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.list_tables)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list-tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.list_tables)
+        [Show boto3-stubs documentation](./client.md#list_tables)
         """
 
     def query_table_rows(
@@ -222,8 +222,8 @@ class HoneycodeClient:
         nextToken: str = None,
     ) -> QueryTableRowsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#query-table-rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
+        [Show boto3-stubs documentation](./client.md#query_table_rows)
         """
 
     def start_table_data_import_job(
@@ -236,8 +236,8 @@ class HoneycodeClient:
         clientRequestToken: str,
     ) -> StartTableDataImportJobResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#start-table-data-import-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
+        [Show boto3-stubs documentation](./client.md#start_table_data_import_job)
         """
 
     @overload
@@ -245,23 +245,23 @@ class HoneycodeClient:
         self, operation_name: Literal["list_table_columns"]
     ) -> ListTableColumnsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)[Show boto3-stubs documentation](./paginators.md#listtablecolumnspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_table_rows"]) -> ListTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)[Show boto3-stubs documentation](./paginators.md#listtablerowspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Paginator.ListTables)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Paginator.ListTables)[Show boto3-stubs documentation](./paginators.md#listtablespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_table_rows"]) -> QueryTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)[Show boto3-stubs documentation](./paginators.md#querytablerowspaginator)
         """
