@@ -1,14 +1,14 @@
 """
 Type annotations for honeycode service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_honeycode.literals import Format
+    from mypy_boto3_honeycode.literals import FormatType
 
-    data: Format = "ACCOUNTING"
+    data: FormatType = "ACCOUNTING"
     ```
 """
 import sys
@@ -20,19 +20,19 @@ else:
 
 
 __all__ = (
-    "Format",
-    "ImportDataCharacterEncoding",
-    "ImportSourceDataFormat",
+    "FormatType",
+    "ImportDataCharacterEncodingType",
+    "ImportSourceDataFormatType",
     "ListTableColumnsPaginatorName",
     "ListTableRowsPaginatorName",
     "ListTablesPaginatorName",
     "QueryTableRowsPaginatorName",
-    "TableDataImportJobStatus",
-    "UpsertAction",
+    "TableDataImportJobStatusType",
+    "UpsertActionType",
 )
 
 
-Format = Literal[
+FormatType = Literal[
     "ACCOUNTING",
     "AUTO",
     "CONTACT",
@@ -45,13 +45,13 @@ Format = Literal[
     "TEXT",
     "TIME",
 ]
-ImportDataCharacterEncoding = Literal[
+ImportDataCharacterEncodingType = Literal[
     "ISO-8859-1", "US-ASCII", "UTF-16", "UTF-16BE", "UTF-16LE", "UTF-8"
 ]
-ImportSourceDataFormat = Literal["DELIMITED_TEXT"]
+ImportSourceDataFormatType = Literal["DELIMITED_TEXT"]
 ListTableColumnsPaginatorName = Literal["list_table_columns"]
 ListTableRowsPaginatorName = Literal["list_table_rows"]
 ListTablesPaginatorName = Literal["list_tables"]
 QueryTableRowsPaginatorName = Literal["query_table_rows"]
-TableDataImportJobStatus = Literal["COMPLETED", "FAILED", "IN_PROGRESS", "SUBMITTED"]
-UpsertAction = Literal["APPENDED", "UPDATED"]
+TableDataImportJobStatusType = Literal["COMPLETED", "FAILED", "IN_PROGRESS", "SUBMITTED"]
+UpsertActionType = Literal["APPENDED", "UPDATED"]
